diff --git a/MdeModulePkg/Universal/Disk/PartitionDxe/Partition.h b/MdeModulePkg/Universal/Disk/PartitionDxe/Partition.h
index 6b0d73438d..d1288bad1c 100644
--- a/MdeModulePkg/Universal/Disk/PartitionDxe/Partition.h
+++ b/MdeModulePkg/Universal/Disk/PartitionDxe/Partition.h
@@ -4,7 +4,7 @@
of the raw block devices media. Currently "El Torito CD-ROM", Legacy
MBR, and GPT partition schemes are supported.
-Copyright (c) 2006 - 2008, Intel Corporation.
+Copyright (c) 2006 - 2009, Intel Corporation.
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -92,6 +92,7 @@ extern EFI_COMPONENT_NAME2_PROTOCOL gPartitionComponentName2;
typedef struct {
BOOLEAN OutOfRange;
BOOLEAN Overlap;
+ BOOLEAN OsSpecific;
} EFI_PARTITION_ENTRY_STATUS;
//
diff --git a/MdeModulePkg/Universal/Disk/PartitionDxe/Gpt.c b/MdeModulePkg/Universal/Disk/PartitionDxe/Gpt.c
index 7bcfe69747..68d5830fcb 100644
--- a/MdeModulePkg/Universal/Disk/PartitionDxe/Gpt.c
+++ b/MdeModulePkg/Universal/Disk/PartitionDxe/Gpt.c
@@ -339,10 +339,12 @@ PartitionInstallGptChildHandles (
for (Index = 0; Index < PrimaryHeader->NumberOfPartitionEntries; Index++) {
if (CompareGuid (&PartEntry[Index].PartitionTypeGUID, &gEfiPartTypeUnusedGuid) ||
PEntryStatus[Index].OutOfRange ||
- PEntryStatus[Index].Overlap
+ PEntryStatus[Index].Overlap ||
+ PEntryStatus[Index].OsSpecific
) {
//
// Don't use null EFI Partition Entries or Invalid Partition Entries
//
continue;
}
@@ -652,6 +654,7 @@ PartitionCheckGptEntry (
EFI_LBA EndingLBA;
UINTN Index1;
UINTN Index2;
+ UINT64 Attributes;
DEBUG ((EFI_D_INFO, " start check partition entries\n"));
for (Index1 = 0; Index1 < PartHeader->NumberOfPartitionEntries; Index1++) {
@@ -687,6 +690,14 @@ PartitionCheckGptEntry (
}
}
+
+ Attributes = PartEntry[Index1].Attributes;
+ if ((Attributes & BIT1) != 0) {
+ //
+ // If Bit 1 is set, this indicate that this is an OS specific GUID partition.
+ //
+ PEntryStatus[Index1].OsSpecific = TRUE;
+ }
}
DEBUG ((EFI_D_INFO, " End check partition entries\n"));
@@ -339,10 +339,12 @@ PartitionInstallGptChildHandles (
) {
//
- // Don't use null EFI Partition Entries or Invalid Partition Entries
+ // Don't use null EFI Partition Entries, Invalid Partition Entries or OS specific
+ // partition Entries
//
continue;